Data Profiling Report
Profiling Date: @profilingDate

Profile Engine: @sakdasVersion
Profile Id: @profilingId
File Name: @fileName
Primary Key: @pk
Missing Condition: @missingCondition
Summary
@totalRecord
Records
@totalColumn
Columns
@blankColumn
Blank Column(s)
@perMissingData
% Missing Data
@ARD
After Remove Duplicated
@dupData
Duplicated Record(s)
@completedData
Completed Record(s)
@perCompletedData
% Completed Record(s)